==> jc-1.4.0.tar.gz: java/awt/PopupMenu__24AccessibleAWTPopupMenu.h <==
// public class java.awt.PopupMenu$AccessibleAWTPopupMenu

// class file dependencies
// @dep_class 40b1e85b7eb42bf7 java_awt_Menu__24AccessibleAWTMenu
// @dep_class 1a6b784cf6e839c6 java_awt_MenuComponent__24AccessibleAWTMenuComponent
// @dep_class 713b3d350e77c7e5 java_awt_MenuItem__24AccessibleAWTMenuItem
// @dep_class 7de2c744f547688f java_awt_PopupMenu__24AccessibleAWTPopupMenu
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Menu__24AccessibleAWTMenu

#include "java/awt/Menu__24AccessibleAWTMenu.h"

#ifndef _JC_java_awt_PopupMenu__24AccessibleAWTPopupMenu_H_
#define _JC_java_awt_PopupMenu__24AccessibleAWTPopupMenu_H_

// Forward structure declarations
struct _jc_java_awt_PopupMenu$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_refs	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_refs;
typedef struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_nonrefs	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_nonrefs;
typedef struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$refs	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$refs;
typedef struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$nonrefs	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$nonrefs;
typedef struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$object	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$object;

typedef const struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vmethods	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vmethods;
typedef const struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtable	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtable;
typedef const struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtype	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtype;

// Constructors
extern void _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$method$_init$946ef2d8c9ef9924(_jc_env *, struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$object *, struct _jc_java_awt_PopupMenu$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$object *);
};

// Vtable
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$vmethods	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
	_jc_java_awt_MenuItem__24AccessibleAWTMenuItem$vmethods	java_awt_MenuItem__24AccessibleAWTMenuItem;
	_jc_java_awt_Menu__24AccessibleAWTMenu$vmethods	java_awt_Menu__24AccessibleAWTMenu;
	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vmethods	java_awt_PopupMenu__24AccessibleAWTPopupMenu;
};

// Vtype
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtype {
	_jc_type			type;
	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_refs {
	struct _jc_java_awt_PopupMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$refs {
    _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_refs	java_awt_PopupMenu__24AccessibleAWTPopupMenu;
    _jc_java_awt_Menu__24AccessibleAWTMenu$sub_refs	java_awt_Menu__24AccessibleAWTMenu;
    _jc_java_awt_MenuItem__24AccessibleAWTMenuItem$sub_refs	java_awt_MenuItem__24AccessibleAWTMenuItem;
    _jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$sub_refs	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$sub_nonrefs	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
    _jc_java_awt_MenuItem__24AccessibleAWTMenuItem$sub_nonrefs	java_awt_MenuItem__24AccessibleAWTMenuItem;
    _jc_java_awt_Menu__24AccessibleAWTMenu$sub_nonrefs	java_awt_Menu__24AccessibleAWTMenu;
    _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_nonrefs	java_awt_PopupMenu__24AccessibleAWTPopupMenu;
};

// Object instance structure
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$object {
	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtype	*vtype;
	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtype _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_PopupMenu__24AccessibleAWTPopupMenu, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$class_object;

#endif	/* _JC_java_awt_PopupMenu__24AccessibleAWTPopupMenu_H_ */

==> jc-1.4.6.tar.gz: java/awt/PopupMenu__24AccessibleAWTPopupMenu.h <==
// public class java.awt.PopupMenu$AccessibleAWTPopupMenu

// class file dependencies
// @dep_class 40b1e85b7eb42bf7 java_awt_Menu__24AccessibleAWTMenu
// @dep_class 8b7c1e30849dcda2 java_awt_MenuComponent__24AccessibleAWTMenuComponent
// @dep_class 3e534b8a534026e0 java_awt_MenuItem__24AccessibleAWTMenuItem
// @dep_class 7de2c744f547688f java_awt_PopupMenu__24AccessibleAWTPopupMenu
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_Menu__24AccessibleAWTMenu

#include "java/awt/Menu__24AccessibleAWTMenu.h"

#ifndef _JC_java_awt_PopupMenu__24AccessibleAWTPopupMenu_H_
#define _JC_java_awt_PopupMenu__24AccessibleAWTPopupMenu_H_

// Forward structure declarations
struct _jc_java_awt_PopupMenu$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;

// Typedefs
typedef struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_refs	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_refs;
typedef struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_nonrefs	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_nonrefs;
typedef struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$refs	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$refs;
typedef struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$nonrefs	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$nonrefs;
typedef struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$object	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$object;

typedef const struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vmethods	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vmethods;
typedef const struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtable	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtable;
typedef const struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtype	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtype;

// Constructors
extern void _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$method$_init$946ef2d8c9ef9924(_jc_env *, struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$object *, struct _jc_java_awt_PopupMenu$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$vmethods	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
	_jc_java_awt_MenuItem__24AccessibleAWTMenuItem$vmethods	java_awt_MenuItem__24AccessibleAWTMenuItem;
	_jc_java_awt_Menu__24AccessibleAWTMenu$vmethods	java_awt_Menu__24AccessibleAWTMenu;
	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vmethods	java_awt_PopupMenu__24AccessibleAWTPopupMenu;
};

// Vtype
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtype {
	_jc_type			type;
	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_refs {
	struct _jc_java_awt_PopupMenu$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$refs {
    _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_refs	java_awt_PopupMenu__24AccessibleAWTPopupMenu;
    _jc_java_awt_Menu__24AccessibleAWTMenu$sub_refs	java_awt_Menu__24AccessibleAWTMenu;
    _jc_java_awt_MenuItem__24AccessibleAWTMenuItem$sub_refs	java_awt_MenuItem__24AccessibleAWTMenuItem;
    _jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$sub_refs	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$sub_nonrefs	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
    _jc_java_awt_MenuItem__24AccessibleAWTMenuItem$sub_nonrefs	java_awt_MenuItem__24AccessibleAWTMenuItem;
    _jc_java_awt_Menu__24AccessibleAWTMenu$sub_nonrefs	java_awt_Menu__24AccessibleAWTMenu;
    _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$sub_nonrefs	java_awt_PopupMenu__24AccessibleAWTPopupMenu;
};

// Object instance structure
struct _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$object {
	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtype	*vtype;
	_jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$vtype _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_PopupMenu__24AccessibleAWTPopupMenu, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_PopupMenu__24AccessibleAWTPopupMenu$class_object;

#endif	/* _JC_java_awt_PopupMenu__24AccessibleAWTPopupMenu_H_ */
